\name{serialize}
\title{Simple Persistent Storage Mechanism}
\usage{
makeShelf(list, file, ascii = TRUE)
makeShelfWriter(file,  ascii = TRUE)
openShelf(file)
listShelf(file)
loadShelf(file, envir = parent.frame())
attachShelf(file, pos = 2, name = paste("shelf", file, sep=":"))
envlist(e)
listIntoEnv(list, e)
envtable()
}
\alias{makeShelf}
\alias{makeShelfWriter}
\alias{openShelf}
\alias{listShelf}
\alias{loadShelf}
\alias{attachShelf}
\alias{envlist}
\alias{listIntoEnv}
\alias{envtable}
\arguments{
  \item{file}{name of gdbm file containing the shelf data}
  \item{list}{named list of values to store in the shelf}
  \item{envir}{an environment}
  \item{pos}{sosition in the search path for attaching}
  \item{e}{environment.}
  \item{list}{a list.}
}
\description{
  Simple persistent storage mechanism that uses a gdbm back end for
  storage and insures that sharing of environments is preserved.
}
\details{
  \code{makeShelf} creates a new data base in \code{file} and saves
  the variable/value pairs specified in \code{list} to the data base
  in a way that allows individual retrieval but preserves sharing of
  environments for values retrieved through the same connection.

  \code{openShelf} creates and returns a connection to a shelf
  connection object.  A shelf connection is a list containing three
  functions that are used to interact with the shelf: \code{getvar}
  returns the value of the variable named by its string argument,
  \code{list} returns a list of all variables in the shelf, and \code{exists}
  can be used to query whether a variable by a specified name exists
  in the shelf.

  \code{makeShelfWriter} creates a new data base in \code{file} and 
  and returns a connection for writing to that file.  A shelf writer
  connection is a list containing one function, \code{putvar}, which
  takes the name, value, and optionally a prefix (default \code{var})
  and a separator (default \code{::}).  A key is constructed by 
  concatenating the prefix, separator and name, and the key/value pair is
  written.  Sharing of environments written through the same connection is
  preserved.

  \code{envlist}, \code{listIntoEnv}, and \code{envtable} are intrnal
  utilities.
}
\examples{
  e <- new.env()
  makeShelf(list(x=e,y=e, z = 3), file="mydb")
  s <- openShelf("mydb")
  s$list()
  s$exists("u")
  s$exists("x")
  s$getvar("x")
}
\keyword{internal}
\author{Luke Tierney}
